#from . import modulo1
from .modulo1 import print_msg

def suma(x, y):
    #modulo1.print_msg("SUMA")
    print_msg("SUMA")
    return x + y


def resta(x, y):
    #modulo1.print_msg("RESTA")
    print_msg("RESTA")
    return x - y


def producto(x, y):
    #modulo1.print_msg("PRODUCTO")
    print_msg("PRODUCTO")
    return x*y


def division(x, y):
    #modulo1.print_msg("DIVISION")
    print_msg("DIVISION")
    return x/y


def info():
    print("suma, resta, producto, division")


# https://python-packaging.readthedocs.io/en/latest/minimal.html
from setuptools import setup


def readme():
      with open("README.rst") as f:
            return f.read()


setup(name="paquete",
      version="0.1",
      description="paquete de operaciones",
      long_description="kepa queton",
      classifiers=["Development Status :: 1 - Planning",
                   "License :: OSI Approved :: GNU General Public License (GPL)",
                   "Programming Language :: Python :: 3.7"],
      keywords="algebra operation",
      url="https://gitlab.com/personal39/paquete.git",
      author="dbp",
      author_email="dbp@ugr.es",
      license="UGR",
      packages=["paquete"],
      install_requires=["numpy"],
      include_package_data=True,
      zip_safe=False,
      test_suite="nose.collector",
      test_require=['nose'],
      )
